lidarwind.wind\_prop\_retrieval.GetWindProperties5Beam
======================================================

.. currentmodule:: lidarwind.wind_prop_retrieval

.. autoclass:: GetWindProperties5Beam

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GetWindProperties5Beam.__init__
      ~GetWindProperties5Beam.calc_hor_wind_comp_continuous
      ~GetWindProperties5Beam.calc_hor_wind_comp_single_dbs
      ~GetWindProperties5Beam.calc_hor_wind_dir
      ~GetWindProperties5Beam.calc_hor_wind_speed
      ~GetWindProperties5Beam.correct_vert_wind_comp
      ~GetWindProperties5Beam.correct_wind_comp
   
   

   
   
   